==> eiffelstudio-16.05.tar: F_code/C2/kl54.c <==
/*
 * Code for class KL_SYSTEM_CLOCK
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl54.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_SYSTEM_CLOCK}.make */
void F75_831 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {KL_SYSTEM_CLOCK}.year */
EIF_INTEGER_32 F75_832 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_);
}


/* {KL_SYSTEM_CLOCK}.month */
EIF_INTEGER_32 F75_833 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_);
}


/* {KL_SYSTEM_CLOCK}.day */
EIF_INTEGER_32 F75_834 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_);
}


/* {KL_SYSTEM_CLOCK}.hour */
EIF_INTEGER_32 F75_835 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_);
}


/* {KL_SYSTEM_CLOCK}.minute */
EIF_INTEGER_32 F75_836 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
}


/* {KL_SYSTEM_CLOCK}.second */
EIF_INTEGER_32 F75_837 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_);
}


/* {KL_SYSTEM_CLOCK}.millisecond */
EIF_INTEGER_32 F75_838 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_);
}


/* {KL_SYSTEM_CLOCK}.set_local_time */
void F75_839 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		tr1 = RTLNS(eif_new_type(10, 0x00).id, 10, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F11_79(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	} else {
		F11_82(RTCW(loc1));
	}
	ti4_1 = F11_83(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_84(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_85(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_86(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_87(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_88(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_0_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.set_utc_time */
void F75_840 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		tr1 = RTLNS(eif_new_type(10, 0x00).id, 10, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F11_80(RTCW(tr1));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	} else {
		F11_82(RTCW(loc1));
	}
	ti4_1 = F11_83(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_84(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_85(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_86(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_87(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F11_88(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_0_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {KL_SYSTEM_CLOCK}.utc_clock */
EIF_REFERENCE F75_841 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {KL_SYSTEM_CLOCK}.local_clock */
EIF_REFERENCE F75_842 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit54 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C2/kl54.c <==
/*
 * Code for class KL_SYSTEM_CLOCK
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl54.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_SYSTEM_CLOCK}.make */
void F77_989 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {KL_SYSTEM_CLOCK}.year */
EIF_INTEGER_32 F77_990 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_);
}


/* {KL_SYSTEM_CLOCK}.month */
EIF_INTEGER_32 F77_991 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_);
}


/* {KL_SYSTEM_CLOCK}.day */
EIF_INTEGER_32 F77_992 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_);
}


/* {KL_SYSTEM_CLOCK}.hour */
EIF_INTEGER_32 F77_993 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_);
}


/* {KL_SYSTEM_CLOCK}.minute */
EIF_INTEGER_32 F77_994 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
}


/* {KL_SYSTEM_CLOCK}.second */
EIF_INTEGER_32 F77_995 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_);
}


/* {KL_SYSTEM_CLOCK}.millisecond */
EIF_INTEGER_32 F77_996 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_);
}


/* {KL_SYSTEM_CLOCK}.set_local_time */
void F77_997 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		loc1 = RTLNS(eif_new_type(6, 0x01).id, 6, _OBJSIZ_1_1_0_1_0_0_0_0_);
		F7_61(RTCW(loc1));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	} else {
		F7_64(RTCW(loc1));
	}
	ti4_1 = F7_65(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_6_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F7_66(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_5_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F7_67(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_4_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F7_68(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F7_69(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F7_70(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F7_71(RTCW(loc1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

void EIF_Minit54 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
